<h1>D-REPR
&nbsp;
<a target="_blank" rel="noopener noreferrer" href="https://camo.githubusercontent.com/de59e8e9b410aa0b9479b114040c06468ef33cfc/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f707974686f6e2d76332e362b2d626c75652e737667"><img src="https://camo.githubusercontent.com/de59e8e9b410aa0b9479b114040c06468ef33cfc/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f707974686f6e2d76332e362b2d626c75652e737667" alt="Python" data-canonical-src="https://img.shields.io/badge/python-v3.6+-blue.svg" style="max-width:100%;"></a>
<a href="https://travis-ci.org/usc-isi-i2/d-repr" rel="nofollow"><img src="https://camo.githubusercontent.com/0c9e33d3fe01292bc75d2f42f8b2f725e6fd0f7a/68747470733a2f2f7472617669732d63692e6f72672f7573632d6973692d69322f642d726570722e7376673f6272616e63683d6d6173746572" alt="Build Status" data-canonical-src="https://travis-ci.org/usc-isi-i2/d-repr.svg?branch=master" style="max-width:100%;"></a>
<a href="https://opensource.org/licenses/MIT" rel="nofollow"><img src="https://camo.githubusercontent.com/890acbdcb87868b382af9a4b1fac507b9659d9bf/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f6c6963656e73652d4d49542d626c75652e737667" alt="License" data-canonical-src="https://img.shields.io/badge/license-MIT-blue.svg" style="max-width:100%;"></a>
</h1>

This library allows reading heterogeneous datasets of different formats and layouts.

For more information, please visit [https://github.com/usc-isi-i2/d-repr](https://github.com/usc-isi-i2/d-repr).
